==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/src/sheet/WSCsheetdef.cpp <==
#include <WScom.h>
#include <WSCsheetdef.h>

#ifndef MSW
char* _WSNrows              = "rows"; 
char* _WSNcols              = "cols"; 
char* _WSNfixedRows         = "fixedRows"; 
char* _WSNfixedCols         = "fixedCols"; 
char* _WSNgridLines         = "gridLines"; 
char* _WSNcelldefWidth      = "cellDefWidth"; 
char* _WSNcelldefHeight     = "cellDefHeight"; 
char* _WSNfixedColHeight    = "fixedColHeight"; 
char* _WSNcellDefFont       = "cellDefFont"; 
char* _WSNfixedCellFont     = "fixedCellFont"; 
char* _WSNeditEnabled       = "editEnabled"; 
char* _WSNhautoNumber       = "hautoNumber"; 
char* _WSNvautoNumber       = "vautoNumber"; 
char* _WSNsheetBackColor    = "sheetBackColor"; 
char* _WSNcellDefBackColor  = "cellDefBackColor"; 
char* _WSNcellDefTextColor  = "cellDefTextColor"; 
char* _WSNfixedBackColor    = "fixedBackColor"; 
char* _WSNfixedTextColor    = "fixedTextColor"; 
char* _WSNgridColor         = "gridColor"; 
char* _WSNdbItem            = "dbItem"; 
char* _WSNsortItem1         = "sortItem1"; 
char* _WSNsort1             = "sort1"; 
char* _WSNsortItem2         = "sortItem2"; 
char* _WSNsort2             = "sort2"; 
char* _WSNsortItem3         = "sortItem3"; 
char* _WSNsort3             = "sort3"; 
//char* _WSNfilter            = "filter"; 
char* _WSNsql               = "sql"; 

#else //MSW
char* _WSNrows              () { return "rows"; };
char* _WSNcols              () { return "cols"; };
char* _WSNfixedRows         () { return "fixedRows"; };
char* _WSNfixedCols         () { return "fixedCols"; };
char* _WSNgridLines         () { return "gridLines"; };
char* _WSNcelldefWidth      () { return "cellDefWidth"; };
char* _WSNcelldefHeight     () { return "cellDefHeight"; };
char* _WSNfixedColHeight    () { return "fixedColHeight"; };
char* _WSNcellDefFont       () { return "cellDefFont"; };
char* _WSNfixedCellFont     () { return "fixedCellFont"; };
char* _WSNeditEnabled       () { return "editEnabled"; };
char* _WSNhautoNumber       () { return "hautoNumber"; };
char* _WSNvautoNumber       () { return "vautoNumber"; };
char* _WSNsheetBackColor    () { return "sheetBackColor"; };
char* _WSNcellDefBackColor  () { return "cellDefBackColor"; };
char* _WSNcellDefTextColor  () { return "cellDefTextColor"; };
char* _WSNfixedBackColor    () { return "fixedBackColor"; };
char* _WSNfixedTextColor    () { return "fixedTextColor"; };
char* _WSNgridColor         () { return "gridColor"; };
char* _WSNdbItem            () { return "dbItem"; };
char* _WSNsortItem1         () { return "sortItem1"; };
char* _WSNsort1             () { return "sort1"; };
char* _WSNsortItem2         () { return "sortItem2"; };
char* _WSNsort2             () { return "sort2"; };
char* _WSNsortItem3         () { return "sortItem3"; };
char* _WSNsort3             () { return "sort3"; };
//char* _WSNfilter            () { return "filter"; };
char* _WSNsql               () { return "sql"; };
#endif //MSW


char* __WSRsort[]={
"X:WSSTR ASC",
"X:WSSTR DESC",
NULL
};
char* __WSRsortD[]={
"0",
"1",
NULL
};

char* __WSRgridLines[]={
"X:WSSTR None",
"X:WSSTR Horz",
"X:WSSTR Vert",
"X:WSSTR Both",
NULL
};
char* __WSRgridLinesD[]={
"0",
"1",
"2",
"3",
NULL
};

char** _WSRsort1(){ return __WSRsort;};
char** _WSRsort1D(){ return __WSRsortD;};
char** _WSRsort2(){ return __WSRsort;};
char** _WSRsort2D(){ return __WSRsortD;};
char** _WSRsort3(){ return __WSRsort;};
char** _WSRsort3D(){ return __WSRsortD;};
char** _WSRgridLines(){ return __WSRgridLines;};
char** _WSRgridLinesD(){ return __WSRgridLinesD;};

char* _WSSrows               (){ return WSGFgettext("p1:WSSTR Row Counter");};
char* _WSScols               (){ return WSGFgettext("p1:WSSTR Column Counter");};
char* _WSSfixedRows          (){ return WSGFgettext("p1:WSSTR Fixed Row Counter");};
char* _WSSfixedCols          (){ return WSGFgettext("p1:WSSTR Fixed Column Counter");};
char* _WSSgridLines          (){ return WSGFgettext("p1:WSSTR Grid Line Type");};
char* _WSScellDefWidth       (){ return WSGFgettext("p1:WSSTR Cell Default Width");};
char* _WSScellDefHeight      (){ return WSGFgettext("p1:WSSTR Cell Default Height");};
char* _WSSfixedColHeight     (){ return WSGFgettext("p1:WSSTR Fixed Cell Height");};
char* _WSScellDefFont        (){ return WSGFgettext("p1:WSSTR Cell Default Font No.");};
char* _WSSfixedCellFont      (){ return WSGFgettext("p1:WSSTR Fixed Cell Default Font No.");};
char* _WSSeditEnabled        (){ return WSGFgettext("p1:WSSTR Edit Enabled");};
char* _WSShautoNumber        (){ return WSGFgettext("p1:WSSTR Fixed Cell Horizontal number drawing");};
char* _WSSvautoNumber        (){ return WSGFgettext("p1:WSSTR Fixed Cell Vertical number drawing");};
char* _WSSsheetBackColor     (){ return WSGFgettext("p1:WSSTR Sheet Back Color");};
char* _WSScellDefBackColor   (){ return WSGFgettext("p1:WSSTR Cell Default Back Color");};
char* _WSScellDefTextColor   (){ return WSGFgettext("p1:WSSTR Cell Default Text Color");};
char* _WSSfixedBackColor     (){ return WSGFgettext("p1:WSSTR Fixed Cell Back Color");};
char* _WSSfixedTextColor     (){ return WSGFgettext("p1:WSSTR Fixed Cell Text Color");};
char* _WSSgridColor          (){ return WSGFgettext("p1:WSSTR Grid Color");};
char* _WSSdbitem             (){ return WSGFgettext("p1:WSSTR DB Select Item");};
char* _WSSsortItem1          (){ return WSGFgettext("p1:WSSTR DB Sort Item1");};
char* _WSSsort1              (){ return WSGFgettext("p1:WSSTR DB Sort1");};
char* _WSSsortItem2          (){ return WSGFgettext("p1:WSSTR DB Sort Item2");};
char* _WSSsort2              (){ return WSGFgettext("p1:WSSTR DB Sort2");};
char* _WSSsortItem3          (){ return WSGFgettext("p1:WSSTR DB Sort Item3");};
char* _WSSsort3              (){ return WSGFgettext("p1:WSSTR DB Sort3");};
char* _WSSsql                (){ return WSGFgettext("p1:WSSTR DB Select SQL");};

==> ws-v3.70.7-src.tar.gz: ws-v3.70-7/src/sheet/WSCsheetdef.cpp <==
#include <WScom.h>
#include <WSCsheetdef.h>

#ifndef MSW
char* _WSNrows              = "rows"; 
char* _WSNcols              = "cols"; 
char* _WSNfixedRows         = "fixedRows"; 
char* _WSNfixedCols         = "fixedCols"; 
char* _WSNgridLines         = "gridLines"; 
char* _WSNcelldefWidth      = "cellDefWidth"; 
char* _WSNcelldefHeight     = "cellDefHeight"; 
char* _WSNfixedColHeight    = "fixedColHeight"; 
char* _WSNcellDefFont       = "cellDefFont"; 
char* _WSNfixedCellFont     = "fixedCellFont"; 
char* _WSNeditEnabled       = "editEnabled"; 
char* _WSNhautoNumber       = "hautoNumber"; 
char* _WSNvautoNumber       = "vautoNumber"; 
char* _WSNsheetBackColor    = "sheetBackColor"; 
char* _WSNcellDefBackColor  = "cellDefBackColor"; 
char* _WSNcellDefTextColor  = "cellDefTextColor"; 
char* _WSNfixedBackColor    = "fixedBackColor"; 
char* _WSNfixedTextColor    = "fixedTextColor"; 
char* _WSNgridColor         = "gridColor"; 
char* _WSNdbItem            = "dbItem"; 
char* _WSNsortItem1         = "sortItem1"; 
char* _WSNsort1             = "sort1"; 
char* _WSNsortItem2         = "sortItem2"; 
char* _WSNsort2             = "sort2"; 
char* _WSNsortItem3         = "sortItem3"; 
char* _WSNsort3             = "sort3"; 
//char* _WSNfilter            = "filter"; 
char* _WSNsql               = "sql"; 
char* _WSNdbCellAutoResize  = "dbCellAutoResize"; 
char* _WSNdbCellTitle       = "dbCellTitle"; 


#else //MSW
char* _WSNrows              () { return "rows"; };
char* _WSNcols              () { return "cols"; };
char* _WSNfixedRows         () { return "fixedRows"; };
char* _WSNfixedCols         () { return "fixedCols"; };
char* _WSNgridLines         () { return "gridLines"; };
char* _WSNcelldefWidth      () { return "cellDefWidth"; };
char* _WSNcelldefHeight     () { return "cellDefHeight"; };
char* _WSNfixedColHeight    () { return "fixedColHeight"; };
char* _WSNcellDefFont       () { return "cellDefFont"; };
char* _WSNfixedCellFont     () { return "fixedCellFont"; };
char* _WSNeditEnabled       () { return "editEnabled"; };
char* _WSNhautoNumber       () { return "hautoNumber"; };
char* _WSNvautoNumber       () { return "vautoNumber"; };
char* _WSNsheetBackColor    () { return "sheetBackColor"; };
char* _WSNcellDefBackColor  () { return "cellDefBackColor"; };
char* _WSNcellDefTextColor  () { return "cellDefTextColor"; };
char* _WSNfixedBackColor    () { return "fixedBackColor"; };
char* _WSNfixedTextColor    () { return "fixedTextColor"; };
char* _WSNgridColor         () { return "gridColor"; };
char* _WSNdbItem            () { return "dbItem"; };
char* _WSNsortItem1         () { return "sortItem1"; };
char* _WSNsort1             () { return "sort1"; };
char* _WSNsortItem2         () { return "sortItem2"; };
char* _WSNsort2             () { return "sort2"; };
char* _WSNsortItem3         () { return "sortItem3"; };
char* _WSNsort3             () { return "sort3"; };
//char* _WSNfilter            () { return "filter"; };
char* _WSNsql               () { return "sql"; };
char* _WSNdbCellAutoResize  () { return "dbCellAutoResize"; };
char* _WSNdbCellTitle       () { return "dbCellTitle"; };

#endif //MSW


char* __WSRsort[]={
"X:WSSTR ASC",
"X:WSSTR DESC",
NULL
};
char* __WSRsortD[]={
"0",
"1",
NULL
};

char* __WSRgridLines[]={
"X:WSSTR None",
"X:WSSTR Horz",
"X:WSSTR Vert",
"X:WSSTR Both",
NULL
};
char* __WSRgridLinesD[]={
"0",
"1",
"2",
"3",
NULL
};

char** _WSRsort1(){ return __WSRsort;};
char** _WSRsort1D(){ return __WSRsortD;};
char** _WSRsort2(){ return __WSRsort;};
char** _WSRsort2D(){ return __WSRsortD;};
char** _WSRsort3(){ return __WSRsort;};
char** _WSRsort3D(){ return __WSRsortD;};
char** _WSRgridLines(){ return __WSRgridLines;};
char** _WSRgridLinesD(){ return __WSRgridLinesD;};

char* _WSSrows               (){ return WSGFgettext("p1:WSSTR Row Counter");};
char* _WSScols               (){ return WSGFgettext("p1:WSSTR Column Counter");};
char* _WSSfixedRows          (){ return WSGFgettext("p1:WSSTR Fixed Row Counter");};
char* _WSSfixedCols          (){ return WSGFgettext("p1:WSSTR Fixed Column Counter");};
char* _WSSgridLines          (){ return WSGFgettext("p1:WSSTR Grid Line Type");};
char* _WSScellDefWidth       (){ return WSGFgettext("p1:WSSTR Cell Default Width");};
char* _WSScellDefHeight      (){ return WSGFgettext("p1:WSSTR Cell Default Height");};
char* _WSSfixedColHeight     (){ return WSGFgettext("p1:WSSTR Fixed Cell Height");};
char* _WSScellDefFont        (){ return WSGFgettext("p1:WSSTR Cell Default Font No.");};
char* _WSSfixedCellFont      (){ return WSGFgettext("p1:WSSTR Fixed Cell Default Font No.");};
char* _WSSeditEnabled        (){ return WSGFgettext("p1:WSSTR Edit Enabled");};
char* _WSShautoNumber        (){ return WSGFgettext("p1:WSSTR Fixed Cell Horizontal number drawing");};
char* _WSSvautoNumber        (){ return WSGFgettext("p1:WSSTR Fixed Cell Vertical number drawing");};
char* _WSSsheetBackColor     (){ return WSGFgettext("p1:WSSTR Sheet Back Color");};
char* _WSScellDefBackColor   (){ return WSGFgettext("p1:WSSTR Cell Default Back Color");};
char* _WSScellDefTextColor   (){ return WSGFgettext("p1:WSSTR Cell Default Text Color");};
char* _WSSfixedBackColor     (){ return WSGFgettext("p1:WSSTR Fixed Cell Back Color");};
char* _WSSfixedTextColor     (){ return WSGFgettext("p1:WSSTR Fixed Cell Text Color");};
char* _WSSgridColor          (){ return WSGFgettext("p1:WSSTR Grid Color");};
char* _WSSdbitem             (){ return WSGFgettext("p1:WSSTR DB Select Item");};
char* _WSSsortItem1          (){ return WSGFgettext("p1:WSSTR DB Sort Item1");};
char* _WSSsort1              (){ return WSGFgettext("p1:WSSTR DB Sort1");};
char* _WSSsortItem2          (){ return WSGFgettext("p1:WSSTR DB Sort Item2");};
char* _WSSsort2              (){ return WSGFgettext("p1:WSSTR DB Sort2");};
char* _WSSsortItem3          (){ return WSGFgettext("p1:WSSTR DB Sort Item3");};
char* _WSSsort3              (){ return WSGFgettext("p1:WSSTR DB Sort3");};
char* _WSSsql                (){ return WSGFgettext("p1:WSSTR DB Select SQL");};
char* _WSSdbCellAutoResize   (){ return WSGFgettext("p1:WSSTR DB Cell Auto Resize");};
char* _WSSdbCellTitle        (){ return WSGFgettext("p1:WSSTR DB Cell Title");};
